<?php
/*Make sure we don't expose any info if called directly*/
if ( !function_exists( 'add_action' ) ) {
    echo 'Hi there!  I\'m just a plugin, not much I can do when called directly.';
    exit;
}

if ( ! class_exists( 'Biography_Customizer_Framework' ) ){
    /**
     * Class for almost all types of customizer fields.
     *
     * @package Biography Customizer Framework
     * @since 1.0.0
     */
    class Biography_Customizer_Framework{
        /*Basic variables for class*/

        /**
         * Variable to hold this framework version
         *
         * @var string
         * @access protected
         * @since 1.0.0
         *
         */
        private  $biography_customizer_framework_version = '1.0.0';

        /**
         * Variable to hold this framework minimum wp version
         *
         * @var string
         * @access protected
         * @since 1.0.0
         *
         */
        protected $biography_customizer_framework_minimum_wp_version = '3.1';

        /**
         * Biography_Customizer_Framework Plugin instance.
         *
         * @see biography_get_instance()
         * @var object
         * @access protected
         * @since 1.0.0
         *
         */
        protected static $biography_instance = NULL;

        /**
         * Variable to hold this framework url
         *
         * @var string
         * @access protected
         * @since 1.0.0
         *
         */
        protected $biography_customizer_framework_url = '';

        /**
         * Variable to hold this framework path
         *
         * @var string
         * @access protected
         * @since 1.0.0
         *
         */
        protected $biography_customizer_framework_path = '';

        /**
         * Name use to save customizer value
         *
         * @var string
         * @access protected
         * @since 1.0.0
         *
         */
        protected $biography_customizer_name = 'biography_customizer';

        /**
         * Holds all basic control types that does not required class
         *
         * @var array
         * @access protected
         * @since 1.0.0
         *
         */
        protected $biography_basic_control_types =
            array(
                'text',
                'text_html',
                'textarea',
                'textarea_html',
                'checkbox',
                'number',
                'number_range',
                'radio',
                'range',
                'select',
                'url',
                'email',
                'password',
                'dropdown-pages',
            );

        /**
         * Holds all panels sections settings
         *
         * @var array
         * @access protected
         * @since 1.0.0
         *
         */
        protected $biography_panels_sections_settings = array();

        /**
         * Holds all panels
         *
         * @var array
         * @access protected
         * @since 1.0.0
         *
         */
        protected $biography_panels = array();

        /**
         * Holds all sections
         *
         * @var array
         * @access protected
         * @since 1.0.0
         *
         */
        protected $biography_sections = array();

        /**
         * Holds same fields repeated settings controls
         *
         * @var array
         * @access protected
         * @since 1.0.0
         *
         */
        public  $biography_repeated_settings_controls = array();

        /**
         * Holds all settings controls
         *
         * @var array
         * @access protected
         * @since 1.0.0
         *
         */
        protected $biography_settings_controls = array();

        /**
         * Holds all panel id to remove
         *
         * @var array
         * @access protected
         * @since 1.0.0
         *
         */
        protected $biography_remove_panels = array();

        /**
         * Holds all section id to remove
         *
         * @var array
         * @access protected
         * @since 1.0.0
         *
         */
        protected $biography_remove_sections = array();

        /**
         * Holds all settings control id to remove
         *
         * @var array
         * @access protected
         * @since 1.0.0
         *
         */
        protected $biography_remove_settings_controls = array();

        /**
         * Access this plugin’s working biography_instance
         *
         * @access public
         * @since 1.0.0
         * @return object of this class
         */
        public static function biography_get_instance() {
            NULL === self::$biography_instance and self::$biography_instance = new self;
            return self::$biography_instance;
        }

        /**
         * Used for regular plugin work.
         *
         * @access public
         * @since 1.0.0
         *
         * @return void
         *
         */
        public function biography_customizer_init($biography_panels_sections_settings = array()) {

            /*Basic variables initialization with filter*/
            if (defined('BIOGRAPHY_CUSTOMIZER_THEME') && BIOGRAPHY_CUSTOMIZER_THEME == 1 ) {
                $this->biography_customizer_framework_url = get_template_directory_uri().'/biography-customizer-framework/';
                $this->biography_customizer_framework_path = get_template_directory().'/biography-customizer-framework/';
            }
            elseif (defined('BIOGRAPHY_CUSTOMIZER_CHILD_THEME') && BIOGRAPHY_CUSTOMIZER_CHILD_THEME == 1) {
                $this->biography_customizer_framework_url = get_stylesheet_directory_uri().'/biography-customizer-framework/';
                $this->biography_customizer_framework_path = get_stylesheet_directory().'/biography-customizer-framework/';
            }
            else {
                $this->biography_customizer_framework_url = plugin_dir_url( __FILE__ ) ;
                $this->biography_customizer_framework_path = plugin_dir_path( __FILE__ );
            }
            $this->biography_customizer_framework_url = apply_filters( 'biography_customizer_framework_url', $this->biography_customizer_framework_url );
            $this->biography_customizer_framework_path = apply_filters( 'biography_customizer_framework_path', $this->biography_customizer_framework_path );

            /*Basic variables initialization with filter*/
            if(defined('BIOGRAPHY_CUSTOMIZER_NAME')){
                $this->biography_customizer_name = BIOGRAPHY_CUSTOMIZER_NAME;
            }


            $this->biography_basic_control_types = apply_filters( 'biography_basic_control_types', $this->biography_basic_control_types );

            $this->biography_panels_sections_settings = $biography_panels_sections_settings;
            $this->biography_panels_sections_settings = apply_filters( 'biography_panels_sections_settings', $this->biography_panels_sections_settings );

            /*Hook before any function of class start */
            do_action( 'biography_customizer_framework_before', $this->biography_panels_sections_settings );

            if(isset($this->biography_panels_sections_settings['panels']) && !empty($this->biography_panels_sections_settings['panels'])){
                $this->biography_panels = $this->biography_panels_sections_settings['panels'];
            }
            if(isset($this->biography_panels_sections_settings['sections']) && !empty($this->biography_panels_sections_settings['sections'])){
                $this->biography_sections = $this->biography_panels_sections_settings['sections'];
            }
            if(isset($this->biography_panels_sections_settings['repeated_settings_controls']) && !empty($this->biography_panels_sections_settings['repeated_settings_controls'])){
                $this->biography_repeated_settings_controls = $this->biography_panels_sections_settings['repeated_settings_controls'];
            }
            if(isset($this->biography_panels_sections_settings['settings_controls']) && !empty($this->biography_panels_sections_settings['settings_controls'])){
                $this->biography_settings_controls = $this->biography_panels_sections_settings['settings_controls'];
            }
            if(isset($this->biography_panels_sections_settings['remove_panels']) && !empty($this->biography_panels_sections_settings['remove_panels'])){
                $this->biography_remove_panels = $this->biography_panels_sections_settings['remove_panels'];
            }
            if(isset($this->biography_panels_sections_settings['remove_sections']) && !empty($this->biography_panels_sections_settings['remove_sections'])){
                $this->biography_remove_sections = $this->biography_panels_sections_settings['remove_sections'];
            }
            if(isset($this->biography_panels_sections_settings['remove_settings_controls']) && !empty($this->biography_panels_sections_settings['remove_settings_controls'])){
                $this->biography_remove_settings_controls = $this->biography_panels_sections_settings['remove_settings_controls'];
            }
            $this->biography_panels = apply_filters( 'biography_panels', $this->biography_panels );

            $this->biography_sections = apply_filters( 'biography_sections', $this->biography_sections );

            $this->biography_repeated_settings_controls = apply_filters( 'biography_repeated_settings_controls', $this->biography_repeated_settings_controls );

            $this->biography_settings_controls = apply_filters( 'biography_settings_controls', $this->biography_settings_controls );

            $this->biography_remove_panels = apply_filters( 'biography_remove_panels', $this->biography_remove_panels );

            $this->biography_remove_sections = apply_filters( 'biography_remove_sections', $this->biography_remove_sections );

            $this->biography_remove_settings_controls = apply_filters( 'biography_remove_settings_controls', $this->biography_remove_settings_controls );

            /*Set default values for panels*/
            if(!empty( $this->biography_panels ) ){
                foreach( $this->biography_panels as $biography_panel_id => $biography_panel ){
                    $this->biography_panels_default_values($biography_panel_id, $biography_panel);
                }
            }

            /*Set default values for sections*/
            if( !empty( $this->biography_sections ) ) {
                foreach( $this->biography_sections as $biography_section_id => $biography_section ){
                    $this->biography_sections_default_values($biography_section_id, $biography_section);
                }
            }

            /*Set default values for biography repeated settings controls*/
            if(!empty($this->biography_repeated_settings_controls)) {
                foreach( $this->biography_repeated_settings_controls as $biography_repeated_setting_control_id => $biography_repeated_setting_control ){
                    $this->biography_repeated_setting_control_default_values( $biography_repeated_setting_control_id, $biography_repeated_setting_control );
                }
            }

            /*Set default values for setting control*/
            if(!empty($this->biography_settings_controls)) {
                foreach( $this->biography_settings_controls as $biography_settings_control_id => $biography_setting_control ){
                    $this->biography_setting_control_default_values($biography_settings_control_id, $biography_setting_control);
                }
            }

            /*Enqueue necessary styles and scripts in  Theme Customizer.*/
            add_action('customize_controls_enqueue_scripts', array($this,'biography_customize_controls_enqueue_scripts'), 12 );

            /*Adding theme customization admin screen*/
            add_action( 'customize_register', array($this,'biography_customize_register'), 12 );

            /*Hook before any function of class end */
            do_action( 'biography_repeated_settings_controls', $this->biography_repeated_settings_controls );
            do_action( 'biography_customizer_framework_after', $this->biography_panels_sections_settings );
        }

        /**
         * Constructor. Intentionally left empty and public.
         *
         * @access public
         * @since 1.0.0
         *
         *
         */
        public function __construct( $biography_customizer_init = array()){
            if(!empty($biography_customizer_init)) {
                $this->biography_customizer_init( $biography_customizer_init );
            }
        }


        /**
         * Function to Set default values for panels
         *
         * @access public
         * @since 1.0.0
         *
         * @param string $biography_panel_id Id of panel
         * @param array $biography_panel Single panel
         * @return void
         *
         */
        public function biography_panels_default_values($biography_panel_id, $biography_panel) {
            $biography_panels_default_values =
                array(
                    'priority'       => 120,
                    'capability'     => 'edit_theme_options',
                    'theme_supports' => '',
                    'title'          => '',
                    'description'    => '',
                );
            $biography_panels_default_values = apply_filters( 'biography_panel_default_values', $biography_panels_default_values);

            $this->biography_panels[$biography_panel_id] =
                array_merge(
                    $biography_panels_default_values,
                    (array)$biography_panel
                );
        }

        /**
         * Function to Set default values for sections
         *
         * @access public
         * @since 1.0.0
         *
         * @param string $biography_section_id Id of section
         * @param array $biography_section Single section
         * @return void
         *
         */
        public function biography_sections_default_values($biography_section_id, $biography_section) {
            $biography_sections_default_values =
                array(
                    'priority'       => 120,
                    'capability'     => 'edit_theme_options',
                    'theme_supports' => '',
                    'title'          => '',
                    'description'    => '',
                    'panel'          => '',
                );
            $biography_sections_default_values = apply_filters( 'biography_sections_default_values', $biography_sections_default_values);

            $this->biography_sections[$biography_section_id] =
                array_merge(
                    $biography_sections_default_values,
                    (array)$biography_section
                );
        }
        /**
         * Function to Set default values for repeated setting controls
         *
         * @access public
         * @since 1.0.0
         *
         * @param string $biography_settings_control_id Id of repeated setting controls
         * @param array $biography_setting_control Single settings control
         * @return void
         *
         */
        public function biography_repeated_setting_control_default_values($biography_repeated_settings_control_id, $biography_repeated_setting_control) {
            if(!empty($biography_repeated_setting_control)) {
                $biography_priority_fixed = 0;
                $biography_repeated_priority = 1;
                $biography_repeated = $biography_repeated_setting_control['repeated'];
                unset($biography_repeated_setting_control['repeated']);
                for( $i=1; $i <= $biography_repeated ; $i++) {
                    foreach( $biography_repeated_setting_control as $biography_settings_control_id => $biography_setting_control ){
                        if( 0 == $biography_priority_fixed ) {
                            $biography_repeated_priority =  $biography_setting_control['control']['priority'];
                        }
                        else {
                            $biography_repeated_priority = $biography_repeated_priority++;

                        }
                        if(isset($biography_setting_control['control']['label'])){
                            $biography_setting_control['control']['label'] = sprintf($biography_setting_control['control']['label'], $i);
                        }
                        $biography_setting_control['control']['priority'] = $biography_repeated_priority;
                        $biography_settings_control_id = $biography_settings_control_id.'_'.$i;

                        $biography_settings_control_id = apply_filters( 'biography_repeated_setting_control_id', $biography_settings_control_id , $biography_setting_control);
                        $biography_setting_control = apply_filters( 'biography_repeated_setting_control', $biography_setting_control, $biography_settings_control_id );

                        $this->biography_settings_controls[$biography_settings_control_id] = $biography_setting_control;

                        $biography_priority_fixed++;
                    }

                }
            }
        }

        /**
         * Function to Set default values for setting controls
         *
         * @access public
         * @since 1.0.0
         *
         * @param string $biography_settings_control_id Id of settings control
         * @param array $biography_setting_control Single settings control
         * @return void
         *
         */
        public function biography_setting_control_default_values( $biography_settings_control_id, $biography_setting_control ) {

            $biography_setting_control_type = $biography_setting_control['control']['type'];
            if( 'text' == $biography_setting_control_type ){
                $biography_default_sanitize_callback = 'sanitize_text_field';
            }
            elseif( 'text_html' == $biography_setting_control_type ){
                $biography_default_sanitize_callback = 'wp_kses_post';
                $biography_setting_control['control']['type'] = 'text';
            }
            elseif( 'textarea' == $biography_setting_control_type ){
                $biography_default_sanitize_callback = 'esc_textarea';
            }
            elseif( 'textarea_html' == $biography_setting_control_type ){
                $biography_default_sanitize_callback = 'wp_kses_post';
                $biography_setting_control['control']['type'] = 'textarea';
            }
            elseif( 'textarea_css' == $biography_setting_control_type ){
                $biography_default_sanitize_callback = 'wp_strip_all_tags';
                $biography_setting_control['control']['type'] = 'textarea';
            }
            elseif( 'checkbox' == $biography_setting_control_type ){
                $biography_default_sanitize_callback = 'biography_sanitize_checkbox';
            }
            elseif( 'number' == $biography_setting_control_type ){
                $biography_default_sanitize_callback = 'biography_sanitize_number';
            }
            elseif( 'number_range' == $biography_setting_control_type ){
                $biography_default_sanitize_callback = 'biography_sanitize_number_range';
                $biography_setting_control['control']['type'] = 'number';
            }
            elseif( 'radio' == $biography_setting_control_type ){
                $biography_default_sanitize_callback = 'biography_sanitize_select';
            }
            elseif( 'range' == $biography_setting_control_type ){
                $biography_default_sanitize_callback = 'biography_sanitize_number_range';
            }
            elseif( 'select' == $biography_setting_control_type ){
                $biography_default_sanitize_callback = 'biography_sanitize_select';
            }
            elseif( 'url' == $biography_setting_control_type ){
                $biography_default_sanitize_callback = 'esc_url_raw';
            }
            elseif( 'email' == $biography_setting_control_type ){
                $biography_default_sanitize_callback = 'biography_sanitize_email';
            }
            elseif( 'password' == $biography_setting_control_type ){
                $biography_default_sanitize_callback = 'sanitize_text_field';/*wp_filter_nohtml_kses*/
            }
            elseif( 'dropdown-pages' == $biography_setting_control_type ){
                $biography_default_sanitize_callback = 'biography_sanitize_post';
            }
            /*WordPress class available*/
            elseif( 'color' == $biography_setting_control_type ){
                $biography_default_sanitize_callback = 'biography_sanitize_hex_color';
            }
            elseif( 'upload' == $biography_setting_control_type ){
                $biography_default_sanitize_callback = 'biography_sanitize_upload';
            }
            elseif( 'image' == $biography_setting_control_type ){
                $biography_default_sanitize_callback = 'biography_sanitize_image';
            }

            /*Biography custom control*/
            elseif( 'post_dropdown' == $biography_setting_control_type ){
                $biography_default_sanitize_callback = 'biography_sanitize_post';
            }
            elseif( 'category_dropdown' == $biography_setting_control_type ){
                $biography_default_sanitize_callback = 'absint';
            }
            elseif( 'radio_image' == $biography_setting_control_type ){
                $biography_default_sanitize_callback = 'biography_sanitize_select';
            }
            elseif( 'tags_dropdown' == $biography_setting_control_type ){
                $biography_default_sanitize_callback = 'absint';
            }
            elseif( 'user_dropdown' == $biography_setting_control_type ){
                $biography_default_sanitize_callback = 'absint';
            }
            elseif('sortable_control'==$biography_setting_control_type){
 
                $biography_default_sanitize_callback = 'biography_sanitize_checkbox';
            }
            else{
                $biography_default_sanitize_callback = 'esc_attr';
            }
            $biography_setting_type = 'theme_mod';
            if (defined('BIOGRAPHY_CUSTOMIZER_OPTION_MODE') && BIOGRAPHY_CUSTOMIZER_OPTION_MODE == 1 ) {
                $biography_setting_type = 'option';
            }
            $biography_setting_default_values =
                array(
                    'type'                 => $biography_setting_type,
                    'capability'           => 'edit_theme_options',
                    'theme_supports'       => '',
                    'default'              => '',
                    'transport'            => 'refresh',
                    'sanitize_callback'    => $biography_default_sanitize_callback,
                    'sanitize_js_callback' => 'esc_attr',
                );
            $biography_control_default_values =
                array(
                    'label'                 => '',
                    'section'               => '',
                    'type'                  => '',
                    'priority'              => 12,
                    'description'           => '',
                    'active_callback'       => '',
                );
            $biography_setting_default_values = apply_filters( 'biography_setting_default_values', $biography_setting_default_values);
            $biography_control_default_values = apply_filters( 'biography_control_default_values', $biography_control_default_values);


            if(!isset($biography_setting_control['setting'])) {
                $biography_setting_control['setting'] = array();
            }
            if(!isset($biography_setting_control['control'])) {
                $biography_setting_control['control'] = array();
            }

            $this->biography_settings_controls[$biography_settings_control_id]['setting'] =
                array_merge(
                    $biography_setting_default_values,
                    (array)$biography_setting_control['setting']
                );
            $this->biography_settings_controls[$biography_settings_control_id]['control'] =
                array_merge(
                    $biography_control_default_values,
                    (array)$biography_setting_control['control']
                );
        }
        /**
         * Enqueue style and scripts at Theme Customizer
         *
         * @access public
         * @since 1.0.0
         *
         * @return void
         *
         */
        function biography_customize_controls_enqueue_scripts(){
            global $pagenow;
            if ( 'customize.php' == $pagenow ) {

                wp_register_style( 'biography-customizer-framework-style', $this->biography_customizer_framework_url . '/assets/css/biography-customizer-framework.css', false, $this->biography_customizer_framework_version );
                wp_enqueue_style( 'biography-customizer-framework-style' );
                wp_enqueue_style( 'biography-customizer-sort-style', trailingslashit( get_template_directory_uri() ) . 'assets/others/sortable/customizer-control.css' );
  
                wp_enqueue_script( 'jquery-ui-core' );
                wp_enqueue_script( 'jquery-ui-sortable' );
                    wp_enqueue_script( 'biography-sortable-customize-controls', trailingslashit( get_template_directory_uri() ) . 'assets/others/sortable/customizer-control.js', array( 'jquery', 'jquery-ui-sortable' ) );
            }
        }

        /**
         * Function to register customizer
         *
         * @access public
         * @since 1.0.0
         *
         * @param object $biography_wp_customize
         * @return void
         *
         */
        public function biography_customize_register( $biography_wp_customize ){

            require_once trailingslashit( $this->biography_customizer_framework_path ) . 'inc/biography-customizer-custom-control.php';

            /*Again adding filter here*/
            $biography_panels = apply_filters( 'biography_register_customize_panel', $this->biography_panels );
            $biography_sections = apply_filters( 'biography_register_customize_sections', $this->biography_sections );
            $biography_settings_controls = apply_filters( 'biography_register_customize_settings_controls', $this->biography_settings_controls );
            $biography_customizer_name = $this->biography_customizer_name;
            $biography_basic_control_types = apply_filters( 'biography_register_customizer_basic_control_types', $this->biography_basic_control_types );
            $biography_remove_panels = apply_filters( 'biography_register_customize_remove_panel', $this->biography_remove_panels );
            $biography_remove_sections = apply_filters( 'biography_register_customize_remove_sections', $this->biography_remove_sections );
            $biography_remove_settings_controls = apply_filters( 'biography_register_customize_remove_settings_controls', $this->biography_remove_settings_controls );

            /*Adding Panels*/
            if ( ! empty( $biography_panels ) ) {
                foreach($biography_panels as $biography_panel_key =>  $biography_panel) {
                    $biography_wp_customize->add_panel( esc_attr( $biography_panel_key ), $biography_panel );
                }
            }

            /*Adding sections*/
            if ( ! empty( $biography_sections ) ) {
                foreach($biography_sections as $biography_section_key =>  $biography_section) {
                    $biography_wp_customize->add_section( esc_attr( $biography_section_key ), $biography_section );
                }
            }


            /*Adding settings controls*/
            if ( ! empty( $biography_settings_controls ) ) {
                foreach($biography_settings_controls as $biography_setting_control_key =>  $biography_settings_control) {
                    do_action('biography_add_setting_control',$biography_wp_customize,$biography_customizer_name, $biography_basic_control_types, $biography_setting_control_key, $biography_settings_control);
                }
            }
            /*Removing Panels*/
            if ( ! empty( $biography_remove_panels ) ) {
                foreach($biography_remove_panels as $biography_remove_panel) {
                    $biography_wp_customize->remove_panel( esc_attr( $biography_remove_panel ));
                }
            }

            /*Removing sections*/
            if ( ! empty( $biography_remove_sections ) ) {
                foreach($biography_remove_sections as $biography_remove_section) {
                    $biography_wp_customize->remove_section( esc_attr( $biography_remove_section ));
                }
            }
            /*Removing settings controls*/
            if ( ! empty( $biography_remove_settings_controls ) ) {
                foreach($biography_remove_settings_controls as $biography_remove_settings_control) {
                    $biography_wp_customize->remove_setting( esc_attr( $biography_remove_settings_control ));
                    $biography_wp_customize->remove_control( esc_attr( $biography_remove_settings_control ));
                }
            }

        }/*END function biography_customize_register*/
    } /*END class Biography_Customizer_Framework*/

    /*Initialize class after theme setup*/
    add_action( 'after_setup_theme', array ( Biography_Customizer_Framework::biography_get_instance(), 'biography_customizer_init' ));
    /*include path for sanitization fields*/
    $biography_current_framework_base_path = plugin_dir_path( __FILE__ );
    require_once trailingslashit( $biography_current_framework_base_path ) . 'inc/biography-customizer-hooks.php';
    require_once trailingslashit( $biography_current_framework_base_path ) . 'inc/biography-sanitization-functions.php';
    require_once trailingslashit( $biography_current_framework_base_path ) . 'inc/biography-customizer-functions.php';
}/*END if(!class_exists('Biography_Customizer_Framework'))*/
