<?php
/**
 * biography Custom Metabox
 *
 * @package biography
 */
$biography_post_types = array(
    'post',
    'page'
);

add_action('add_meta_boxes', 'biography_add_layout_metabox');
function biography_add_layout_metabox() {
    global $post;
    $frontpage_id = get_option('page_on_front');
    if( $post->ID == $frontpage_id ){
        return;
    }

    global $biography_post_types;
    foreach ( $biography_post_types as $post_type ) {
        add_meta_box(
            'biography_layout_options', // $id
            esc_html__( 'Layout options', 'biography' ), // $title
            'biography_layout_options_callback', // $callback
            $post_type, // $page
            'normal', // $context
            'high'// $priority
        );
    }

}

/* biography sidebar layout */
$biography_default_layout_options = array(
    'left-sidebar' => array(
        'value'     => 'left-sidebar',
        'thumbnail' => get_template_directory_uri() . '/inc/images/left-sidebar.png'
    ),
    'right-sidebar' => array(
        'value' => 'right-sidebar',
        'thumbnail' => get_template_directory_uri() . '/inc/images/right-sidebar.png'
    ),
    'no-sidebar' => array(
        'value'     => 'no-sidebar',
        'thumbnail' => get_template_directory_uri() . '/inc/images/no-sidebar.png'
    )
);
/* biography featured layout */
$biography_single_post_image_align_options = array(
    'full' => array(
        'value' => 'full',
        'label' => esc_html__( 'Full', 'biography' )
    ),
    'right' => array(
        'value' => 'right',
        'label' => esc_html__( 'Right ', 'biography' ),
    ),
    'left' => array(
        'value'     => 'left',
        'label' => esc_html__( 'Left', 'biography' ),
    ),
    'no-image' => array(
        'value'     => 'no-image',
        'label' => esc_html__( 'No Image', 'biography' )
    )
);

function biography_layout_options_callback() {

    global $post , $biography_default_layout_options, $biography_single_post_image_align_options;
    $biography_customizer_saved_values = biography_get_all_options(1);

    /*default banner image*/
    // $biography_banner_image = $biography_customizer_saved_values['biography-header-image'];
    $biography_banner_image = get_header_image();

    /*biography default layout*/
    $biography_single_sidebar_layout = $biography_customizer_saved_values['biography-default-layout'];

    /*biography-single-post-image-align*/
    $biography_single_post_image_align = $biography_customizer_saved_values['biography-single-post-image-align'];

    wp_nonce_field( basename( __FILE__ ), 'biography_layout_options_nonce' );
    ?>
    <style>
        .hide-radio{
            position: relative;
            margin-bottom: 6px;
        }

        .hide-radio img, .hide-radio label{
            display: block;
        }

        .hide-radio input[type="radio"]{
            position: absolute;
            left: 50%;
            top: 50%;
            opacity: 0;
        }

        .hide-radio input[type=radio] + label {
            border: 3px solid #F1F1F1;
        }

        .hide-radio input[type=radio]:checked + label {
            border: 3px solid #CCC;
        }
    </style>
    <table class="form-table page-meta-box">
        <!--Image alignment-->
        <tr>
            <td colspan="4"><?php esc_html_e( 'Banner Image', 'biography' ); ?></td>
        </tr>
        <tr>
            <td>
                <label for="biography_banner_image">
                    <?php esc_html_e( 'Select Banner Image', 'biography' ); ?>
                </label>
                <br />
                <small><?php esc_html_e( 'Please note that if you remove this image default banner image will appear', 'biography' ); ?></small>
                <?php
                $biography_banner_image_meta = get_post_meta( $post->ID, 'biography-banner-image', true );
                if( !empty ( $biography_banner_image_meta ) ){
                    $biography_banner_image = $biography_banner_image_meta;
                }
                if(!empty( $biography_banner_image )){
                    ?>
                    <img class="biography-banner-image widefat" src="<?php echo esc_url( $biography_banner_image ); ?>" />
                    <?php
                }
                ?>
                <input type="text" class="widefat biography_widget_image" name="biography-banner-image" id="biography-banner-image" value="<?php echo esc_url( $biography_banner_image ); ?>" />
                <input type="button" value="<?php esc_attr_e( 'Upload Image', 'biography' ); ?>" class="button biography_media_image_upload" data-title="<?php esc_attr_e( 'Banner image','biography'); ?>" data-button="<?php esc_attr_e( 'Select Banner Image','biography'); ?>"/>
                <input type="button" value="<?php esc_attr_e( 'Remove Image', 'biography' ); ?>" class="button biography_media_image_remove" data-title="<?php esc_attr_e( 'Banner image','biography'); ?>" data-button="<?php esc_attr_e( 'Select banner image','biography'); ?>"/>
            </td>
        </tr>

        <tr>
            <td colspan="4"><em class="f13"><?php esc_html_e( 'Choose Sidebar Template', 'biography' ); ?></em></td>
        </tr>

        <tr>
            <td>
                <?php
                $biography_single_sidebar_layout_meta = get_post_meta( $post->ID, 'biography-default-layout', true );
                if( false != $biography_single_sidebar_layout_meta ){
                   $biography_single_sidebar_layout = $biography_single_sidebar_layout_meta;
                }
                foreach ($biography_default_layout_options as $field) {
                    ?>
                    <div class="hide-radio radio-image-wrapper" style="float:left; margin-right:30px;">
                        <input id="<?php echo esc_attr( $field['value'] ); ?>" type="radio" name="biography-default-layout"
                               value="<?php echo esc_attr( $field['value'] ); ?>"
                            <?php checked( $field['value'], $biography_single_sidebar_layout ); ?>/>
                        <label class="description" for="<?php echo esc_attr( $field['value'] ); ?>">
                            <img src="<?php echo esc_url( $field['thumbnail'] ); ?>" />
                        </label>
                    </div>
                <?php } // end foreach
                ?>
                <div class="clear"></div>
            </td>
        </tr>
        <tr>
            <td><em class="f13"><?php esc_html_e( 'You can set up the sidebar content', 'biography' ); ?> <a href="<?php echo esc_url( admin_url('/widgets.php') ); ?>"><?php esc_html_e( 'here', 'biography' ); ?></a></em></td>
        </tr>

        <!--Image alignment-->
        <tr>
            <td colspan="4"><?php esc_html_e( 'Featured Image Alignment', 'biography' ); ?></td>
        </tr>
        <tr>
            <td>
                <?php
                $biography_single_post_image_align_meta = get_post_meta( $post->ID, 'biography-single-post-image-align', true );
                if( false != $biography_single_post_image_align_meta ){
                    $biography_single_post_image_align = $biography_single_post_image_align_meta;
                }
                foreach ($biography_single_post_image_align_options as $field) {
                    ?>
                    <input id="<?php echo esc_attr( $field['value'] ); ?>" type="radio" name="biography-single-post-image-align" value="<?php echo esc_attr( $field['value'] ); ?>" <?php checked( $field['value'], $biography_single_post_image_align ); ?>/>
                    <label class="description" for="<?php echo esc_attr( $field['value'] ); ?>">
                        <?php echo esc_html( $field['label'] ); ?>
                    </label>
                <?php } // end foreach
                ?>
                <div class="clear"></div>
            </td>
        </tr>
        <!--Disable in recent posts-->
        <?php
        if( 'post' == $post->post_type ){
            ?>
            <tr>
                <td>
                    <?php
                    $biography_disable_recent_posts = 0;
                    $biography_disable_recent_posts_meta = get_post_meta( $post->ID, 'biography-disable-in-recent-posts', true );
                    if( 0 != $biography_disable_recent_posts_meta ){
                        $biography_disable_recent_posts = $biography_disable_recent_posts_meta;
                    }
                    ?>
                    <input id="biography-disable-in-recent-posts" type="checkbox" name="biography-disable-in-recent-posts" <?php checked( 1, $biography_disable_recent_posts ); ?>/>
                    <label class="description" for="biography-disable-in-recent-posts">
                        <?php esc_html_e('Exclude It From Blog Posts', 'biography'); ?>
                    </label>
                    <div class="clear"></div>
                </td>
            </tr>
            <?php
        }
        ?>
    </table>

<?php }

/**
 * save the custom metabox data
 * @hooked to save_post hook
 */
function biography_save_sidebar_layout( $post_id ) {
    global $post;
    // Verify the nonce before proceeding.
    if ( !isset( $_POST[ 'biography_layout_options_nonce' ] ) || !wp_verify_nonce( sanitize_key( $_POST[ 'biography_layout_options_nonce' ] ), basename( __FILE__ ) ) ) {
        return;
    }

    // Stop WP from clearing custom fields on autosave
    if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
        return;
    }

    if ( !current_user_can( 'edit_page', $post_id ) ) {
        return $post_id;
    }

    if(isset($_POST['biography-default-layout'])){
        $old = get_post_meta( $post_id, 'biography-default-layout', true);
        $new = $_POST['biography-default-layout'];
        if ($new && $new != $old) {
            update_post_meta($post_id, 'biography-default-layout', sanitize_text_field( $new ) );
        } elseif ('' == $new && $old) {
            delete_post_meta($post_id,'biography-default-layout', $old);
        }
    }


    /*image layout biography-image-align*/
    if(isset($_POST['biography-single-post-image-align'])){
        $old = get_post_meta( $post_id, 'biography-single-post-image-align', true);
        $new = $_POST['biography-single-post-image-align'];
        if ($new && $new != $old) {
            update_post_meta($post_id, 'biography-single-post-image-align', sanitize_text_field( $new ) );
        } elseif ('' == $new && $old) {
            delete_post_meta($post_id,'biography-single-post-image-align', $old);
        }
    }

    if( 'post' == $post->post_type ){
        /*biography-disable-in-recent-posts*/
        if(isset($_POST['biography-disable-in-recent-posts']) ){
            update_post_meta($post_id, 'biography-disable-in-recent-posts', 1);
        }
        else{
            update_post_meta($post_id, 'biography-disable-in-recent-posts', 0);
        }
    }

    /*banner image*/
    if(isset($_POST['biography-banner-image'])){
        $new = $_POST['biography-banner-image'];
        update_post_meta($post_id, 'biography-banner-image', esc_url_raw( $new ) );
    }
}
add_action('save_post', 'biography_save_sidebar_layout');

function biography_image_upload_scripts() {
    wp_enqueue_media();
    wp_enqueue_script('biography-script', get_template_directory_uri(). '/inc/post-meta/image-upload.js', array('jquery'), '1.0', true);
}
add_action('admin_enqueue_scripts', 'biography_image_upload_scripts');


if( ! function_exists( 'biography_banner_image' ) ) :
    /**
     * Biography banner image
     *
     * @since  Biography 1.0.0
     *
     * @param int
     * @return string
     */
    function biography_banner_image( $post_id = null ){
        global $biography_customizer_all_values,$post;
        $biography_banner_image = get_header_image();
        if( null ==  $post_id && isset( $post->ID )){
            $post_id = $post->ID;
        }
        if( !empty( $post_id )){
            $post_id = $post->ID;
            $biography_banner_image_meta = get_post_meta( $post_id, 'biography-banner-image', true );
            if( !empty( $biography_banner_image_meta ) ) {
                $biography_banner_image = $biography_banner_image_meta;
            }
        }
        return $biography_banner_image;
    }
endif;
